<?php

namespace Drupal\elevatezoomplus;

use Drupal\blazy\BlazyDefault;

/**
 * Defines shared plugin default settings.
 */
class ElevateZoomPlusDefault extends BlazyDefault {

  /**
   * {@inheritdoc}
   */
  public static function baseSettings() {
    return [
      'elevatezoomplus' => 'default',
    ] + parent::baseSettings();
  }

  /**
   * Returns fieldable entity formatter and Views settings.
   */
  public static function extendedSettings() {
    return self::baseSettings() + parent::extendedSettings();
  }

  /**
   * Returns a wrapper to pass tests, or DI where adding params is troublesome.
   *
   * @todo remove for Blazy::fileUrlGenerator by D10 when D8 is dropped.
   */
  public static function fileUrlGenerator() {
    return \Drupal::hasService('file_url_generator') ? \Drupal::service('file_url_generator') : NULL;
  }

  /**
   * Creates an absolute web-accessible URL string.
   *
   * @todo remove for BlazyFile::createUrl post Blazy:2.6+.
   */
  public static function createUrl($uri): string {
    if ($gen = self::fileUrlGenerator()) {
      return $gen->generateAbsoluteString($uri);
    }

    $function = 'file_create_url';
    return is_callable($function) ? $function($uri) : '';
  }

  /**
   * Transforms an absolute URL of a local file to a relative URL.
   *
   * @todo remove for BlazyFile::transformRelative post Blazy:2.6+.
   */
  public static function transformRelative($uri, $style = NULL): string {
    $url = $style ? $style->buildUrl($uri) : self::createUrl($uri);

    if ($gen = self::fileUrlGenerator()) {
      return $gen->transformRelative($url);
    }

    $function = 'file_url_transform_relative';
    return is_callable($function) ? $function($url) : '';
  }

}
